## [1.4.1](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.4.0...v1.4.1) (2025-04-18)


### Bug Fixes

* update goose cli client name ([#77](https://github.com/pathintegral-institute/mcpm.sh/issues/77)) ([6b17d94](https://github.com/pathintegral-institute/mcpm.sh/commit/6b17d94f97cf0b4d01ad1f11e8b1abb169afc509))

# [1.4.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.3.0...v1.4.0) (2025-04-18)


### Features

* **router:** Improve function naming in router ([654872d](https://github.com/pathintegral-institute/mcpm.sh/commit/654872dec5d7588f115bab67a08ac2779e9383f3))

# [1.3.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.2.0...v1.3.0) (2025-04-18)


### Features

* add share for router ([#74](https://github.com/pathintegral-institute/mcpm.sh/issues/74)) ([e81a852](https://github.com/pathintegral-institute/mcpm.sh/commit/e81a85214f2287acea2b6b667a47a0e7d6f5e462))

# [1.2.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.1.2...v1.2.0) (2025-04-17)


### Features

* **command:** Add info command and simplify search output ([#73](https://github.com/pathintegral-institute/mcpm.sh/issues/73)) ([27a4443](https://github.com/pathintegral-institute/mcpm.sh/commit/27a44434c5afe72ee1ceec1b2ef2b6b6a1698f5f))

## [1.1.2](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.1.1...v1.1.2) (2025-04-17)


### Bug Fixes

* add should remove optional argument placeholder ([#62](https://github.com/pathintegral-institute/mcpm.sh/issues/62)) ([9181610](https://github.com/pathintegral-institute/mcpm.sh/commit/9181610fb886944df172f60a5112d20893e25a87))
* update the default user-agent for web-fetch ([#70](https://github.com/pathintegral-institute/mcpm.sh/issues/70)) ([15df122](https://github.com/pathintegral-institute/mcpm.sh/commit/15df12212a7a8ffc9d0ae98d0420cae448fff92a))
